@@ -4,14 +4,17 @@
 #'
 #' @template paging
 #' @template args
+#' @template key
 #' @examples \dontrun{
 #' package_list_current()
 #' package_list_current(as = 'json')
 #' package_list_current(as = 'table')
 #' }
-package_list_current <- function(offset = 0, limit = 31,
-                                 url = get_default_url(), as = 'list', ...) {
-  body <- cc(list(offset = offset, limit = limit))
-  res <- ckan_POST(url, 'current_package_list_with_resources', body = body, ...)
+package_list_current <- function(offset = 0, limit = 31, url = get_default_url(),
+  key = get_default_key(), as = 'list', ...) {
+
+  args <- cc(list(offset = offset, limit = limit))
+  res <- ckan_GET(url, 'current_package_list_with_resources', args, key = key,
+    ...)
   switch(as, json = res, list = jsl(res), table = jsd(res))
 }
