@@ -3,13 +3,16 @@
 #' @export
 #'
 #' @template args
+#' @template key
 #' @examples \dontrun{
 #' ping()
 #' ping(as = "json")
 #' }
-ping <- function(url = get_default_url(), as = "logical", ...) {
+ping <- function(url = get_default_url(), key = get_default_key(),
+  as = "logical", ...) {
+  
   tryCatch({
-    res <- ckan_POST(url, 'site_read', ...)
+    res <- ckan_GET(url, 'site_read', key = key, ...)
     switch(as, json = res, logical = jsd(res))
   }, error = function(e) FALSE)
 }
