@@ -7,7 +7,7 @@
 #' @template key
 #' @examples \dontrun{
 #' # Setup
-#' ckanr_setup(url = "http://demo.ckan.org", key = getOption("ckan_demo_key"))
+#' ckanr_setup(url = "https://demo.ckan.org", key = getOption("ckan_demo_key"))
 #'
 #' # Get a resource
 #' res <- resource_show("b85948b6-f9ea-4392-805e-00511d6cf6c6")
@@ -19,10 +19,11 @@
 #' # or pass id in directly
 #' # resource_patch(x, id = res$id)
 #' }
-resource_patch <- function(x, id, key = get_default_key(),
-                           url = get_default_url(), as = 'list', ...) {
+resource_patch <- function(x, id, url = get_default_url(),
+  key = get_default_key(), as = 'list', ...) {
+  
   id <- as.ckan_resource(id, url = url)
-  if (!is(x, "list")) {
+  if (!inherits(x, "list")) {
     stop("x must be of class list", call. = FALSE)
   }
   x$id <- id$id
