@@ -4,9 +4,10 @@
 #'
 #' @param id (character) Resource identifier.
 #' @template args
+#' @template key 
 #' @examples \dontrun{
 #' # Setup
-#' ckanr_setup(url = "http://demo.ckan.org/", key = getOption("ckan_demo_key"))
+#' ckanr_setup(url = "https://demo.ckan.org/", key = Sys.getenv("CKAN_DEMO_KEY"))
 #'
 #' # create a package
 #' (res <- package_create("yellow7"))
@@ -28,8 +29,11 @@
 #' resource_show(id = "05ff2255-c38a-40c9-b657-4ccb55ab2feb",
 #'               url = "http://data.nhm.ac.uk")
 #' }
-resource_show <- function(id, url = get_default_url(), as = 'list', ...) {
+resource_show <- function(id, url = get_default_url(), key = get_default_key(),
+  as = 'list', ...) {
+
   id <- as.ckan_resource(id, url = url)
-  res <- ckan_POST(url, 'resource_show', body = list(id = id$id), ...)
-  switch(as, json = res, list = as_ck(jsl(res), "ckan_resource"), table = jsd(res))
+  res <- ckan_GET(url, 'resource_show', list(id = id$id), key = key, ...)
+  switch(as, json = res, list = as_ck(jsl(res), "ckan_resource"),
+    table = jsd(res))
 }
