@@ -8,6 +8,7 @@
 #' if give only tags that belong to this vocabulary will be returned
 #' @template paging
 #' @template args
+#' @template key
 #' @examples \dontrun{
 #' tag_search(query = 'ta')
 #'
@@ -16,10 +17,12 @@
 #' tag_search(query = 'ta', as = 'table')
 #' }
 tag_search <- function(query = NULL, vocabulary_id = NULL,
-                       offset = 0, limit = 31,
-                       url = get_default_url(), as = 'list', ...) {
-  body <- cc(list(query = query, vocabulary_id = vocabulary_id,
+  offset = 0, limit = 31, url = get_default_url(), key = get_default_key(),
+  as = 'list', ...) {
+
+  args <- cc(list(query = query, vocabulary_id = vocabulary_id,
                   offset = offset, limit = limit))
-  res <- ckan_POST(url, 'tag_search', body = body, ...)
-  switch(as, json = res, list = lapply(jsl(res)$results, as.ckan_tag), table = jsd(res))
+  res <- ckan_GET(url, 'tag_search', args, key = key, ...)
+  switch(as, json = res, list = lapply(jsl(res)$results, as.ckan_tag),
+    table = jsd(res))
 }
