@@ -4,9 +4,10 @@
 #' @param id (character) User identifier.
 #' @template paging
 #' @template args
+#' @template key
 #' @examples \dontrun{
 #' # Setup
-#' ckanr_setup(url = "http://demo.ckan.org/", key = getOption("ckan_demo_key"))
+#' ckanr_setup(url = "https://demo.ckan.org/", key = getOption("ckan_demo_key"))
 #'
 #' # list package activity
 #' user_activity_list('sckottie')
@@ -20,9 +21,10 @@
 #' user_activity_list(x, as = "json")
 #' }
 user_activity_list <- function(id, offset = 0, limit = 31,
-                                  url = get_default_url(), as = "list", ...) {
+  url = get_default_url(), key = get_default_key(), as = "list", ...) {
+
   id <- as.ckan_user(id, url = url)
-  body <- cc(list(id = id$id, offset = offset, limit = limit))
-  res <- ckan_POST(url, 'user_activity_list', body = body, ...)
+  args <- cc(list(id = id$id, offset = offset, limit = limit))
+  res <- ckan_GET(url, 'user_activity_list', args, key = key, ...)
   switch(as, json = res, list = jsl(res), table = jsd(res))
 }
