@@ -1,10 +1,13 @@
 context("changes")
 
+skip_on_cran()
+
 u <- get_test_url()
 
 test_that("changes gives back expected class types", {
-  check_ckan()
-  a <- changes(url=u)
+  check_ckan(u)
+  cat(u, sep = "\n")
+  a <- changes(url = u)
 
   expect_is(a, "list")
   expect_is(a[[1]], "list")
@@ -13,8 +16,8 @@ test_that("changes gives back expected class types", {
 })
 
 test_that("changes works giving back json output", {
-  check_ckan()
-  b <- changes(url=u, as = 'json')
+  check_ckan(u)
+  b <- changes(url = u, as = 'json')
   b_df <- jsonlite::fromJSON(b)
 
   expect_is(b, "character")
@@ -23,10 +26,10 @@ test_that("changes works giving back json output", {
 })
 
 test_that("changes fails correctly", {
-  check_ckan()
+  check_ckan(u)
 
   expect_error(changes("adf"), "offset Invalid integer")
   expect_error(changes(limit = "Adf"), "limit Invalid integer")
   expect_error(changes("adf", url = "http://www.google.com"),
-               regexp = "client error: \\(404\\) Not Found")
+               regexp = "404")
 })
