@@ -1,9 +1,12 @@
 context("tag_list")
+
+skip_on_cran()
+
 u <- get_test_url()
 
 tag_num <- local({
   check_ckan(u)
-  res <- httr::GET(file.path(u, "/api/3/action/tag_list"))
+  res <- httr::GET(file.path(u, "api/3/action/tag_list"))
   httr::stop_for_status(res)
   json <- httr::content(res, as = "parsed")
   length(json$result)
